Репозиторий Sisyphus
Последнее обновление: 1 октября 2023 | Пакетов: 18631 | Посещений: 37751896
en ru br
Репозитории ALT
5.1: 1.6f-alt11
4.1: 1.6f-alt1
4.0: 1.5m2-alt4
+backports:1.6f-alt5.M40.1
3.0: 1.5m2-alt3
www.altlinux.org/Changes

Группа :: Система/Основа
Пакет: man

 Главная   Изменения   Спек   Патчи   Sources   Загрузить   Gear   Bugs and FR  Repocop 

Патч: man-1.5m2-alt-bzip2.patch
Скачать


--- man-1.5m2/configure.vns	2004-05-26 15:29:28 +0400
+++ man-1.5m2/configure	2004-05-26 15:38:53 +0400
@@ -991,7 +991,7 @@
   then
     DO_COMPRESSION=true
     compress=
-    for i in bzip2 gzip bzip tzip pack compress freeze yabba
+    for i in bzip2
     do
       eval F$i=missing
       for j in $DEFPATH
 
дизайн и разработка: Vladimir Lettiev aka crux © 2004-2005, Andrew Avramenko aka liks © 2007-2008
текущий майнтейнер: Michael Shigorin
--- man-1.5m2/src/man.c.vns	2003-09-05 13:49:13 +0400
+++ man-1.5m2/src/man.c	2004-05-26 15:29:28 +0400
@@ -332,13 +332,21 @@
 	  /*
 	   * Some people have compressed man pages, but uncompressed
 	   * .so files - we could glob for all possible extensions,
 	   * for now: only try .gz
 	   */
-	  else if (fp == NULL && get_expander(".gz") &&
-		   strlen(name)+strlen(".gz") < BUFSIZE) {
-	       strcat(name, ".gz");
+	  if (fp == NULL) {
+	       unsigned offset = strlen(name);
+	  if (get_expander(".gz") &&
+		   offset+sizeof(".gz") <= BUFSIZE) {
+	       strcpy(name + offset, ".gz");
+	       fp = fopen (name, "r");
+	  }
+	  if (fp == NULL && get_expander(".bz2") &&
+		   offset+sizeof(".bz2") <= BUFSIZE) {
+	       strcpy(name + offset, ".bz2");
 	       fp = fopen (name, "r");
 	  }
+	  }
 
 	  if (fp == NULL) {
 	       perror("fopen");
@@ -332,13 +332,21 @@
 	   * Some people have compressed man pages, but uncompressed
 	   * .so files - we could glob for all possible extensions,
-	   * for now: only try .gz
+	   * for now: only try .gz and .bz2
 	   */